@@ -49,12 +49,8 @@
 
 package com.openexchange.oauth.twitter;
 
-import com.openexchange.config.ConfigurationService;
-import com.openexchange.config.cascade.ConfigViewFactory;
-import com.openexchange.exception.OXException;
 import com.openexchange.oauth.API;
 import com.openexchange.oauth.AbstractOAuthServiceMetaData;
-import com.openexchange.session.Session;
 
 /**
  * {@link OAuthServiceMetaDataTwitterImpl}
@@ -63,16 +59,6 @@ import com.openexchange.session.Session;
  */
 public class OAuthServiceMetaDataTwitterImpl extends AbstractOAuthServiceMetaData {
 
-    /**
-     * The default API key.
-     */
-    private static final String KEY_API = "";
-
-    /**
-     * The default secret key.
-     */
-    private static final String KEY_SECRET = "";
-
     public OAuthServiceMetaDataTwitterImpl() {
         super();
         setAPIKeyName("com.openexchange.twitter.consumerKey");
